@@ -23,11 +23,14 @@ class SSH(Brute):
         user, pwd = arg
         try:
             client = paramiko.SSHClient()
-            client.connect(hostname=self.addr,
-                           port=self.port,
-                           username=user,
-                           password=pwd,
-                           timeout=20)
+            client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+            client.connect(
+                hostname=self.addr,
+                port=self.port,
+                username=user,
+                password=pwd,
+                timeout=20
+            )
             res.append(arg)
             return True
         except Exception as e:
