@@ -8,30 +8,34 @@ from saker.utils.daemon import Daemon
 
 def port(args):
     parser = argparse.ArgumentParser(
-        description='Saker Port Scanner',
-        usage='[options]',
-        epilog='Nmap wrapper'
+        description="Saker Port Scanner",
+        usage="[options]",
+        epilog="Nmap wrapper"
     )
     parser.add_argument(
-        "-t", '--target',
+        "-t", "--target",
         dest="target", help="define scan target"
     )
     parser.add_argument(
-        "-f", '--file',
+        "-f", "--file",
         dest="file", help="use file as scan target"
     )
     parser.add_argument(
-        '-b', '--background', action="store_true",
-        help='run port scanner in background with unix daemon, only support unix platform'
+        "-b", "--background", action="store_true",
+        help="run port scanner in background with unix daemon, only support unix platform"
+    )
+    parser.add_argument(
+        "-p", "--port",
+        dest="port", help="scan port scope"
     )
     opts = parser.parse_args(args)
 
     targets = []
-    task = ''
+    task = ""
 
     if opts.file:
         task = opts.file
-        with open(opts.file, 'r') as fh:
+        with open(opts.file, "r") as fh:
             for domain in fh:
                 targets.append(domain.strip())
 
@@ -48,9 +52,9 @@ def port(args):
             Nmap(target).dump()
 
     if opts.background:
-        pidfile = '%s.pid' % task
-        logfile = '%s.log' % task
-        errfile = '%s.err' % task
+        pidfile = "%s.pid" % task
+        logfile = "%s.log" % task
+        errfile = "%s.err" % task
         d = Daemon(pidfile, stdout=logfile, stderr=errfile)
         d.start(_nmapScan, targets)
     else:
