@@ -1,8 +1,7 @@
-import ssl
-import socket
-
 from urllib.parse import urlparse
 
+from saker.core.sock import tcpSock
+
 
 class RawHTTP(object):
 
@@ -11,7 +10,6 @@ class RawHTTP(object):
 
     def __init__(self):
         super(RawHTTP, self).__init__()
-        self.socket = None
 
     def construct(self, method='GET', url='/', headers={}, body='', version='HTTP/1.1'):
         data = self.template
@@ -25,31 +23,22 @@ class RawHTTP(object):
             strHeader += '%s: %s%s' % (k, headers[k], self.split)
         data = data.replace('<headers>', strHeader)
         data = data.replace('<entity-body>', body)
-        return data
+        return data.encode()
+
+    def connect(self, url):
+        url = urlparse(url)
+        addr = url.netloc.split(":")[0]
+        port = url.port
+        if port is None:
+            port = [80, 443][url.scheme == "https"]
+        conn = tcpSock(addr, port, url.scheme == "https")
+        return conn
 
     def sendBytes(self, url, req):
-        url = urlparse(url)
-        if self.socket is None:
-            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        else:
-            s = self.socket(socket.AF_INET, socket.SOCK_STREAM)
-        if url.scheme == 'https':
-            context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
-            context.verify_mode = ssl.CERT_NONE
-            s = context.wrap_socket(s, server_hostname=url.hostname)
-        s.connect((addr, url.port))
+        s = self.connect(url)
         if isinstance(req, str):
             req = req.encode()
         s.send(req)
         resp = s.recv(4096)
         s.close()
         return resp
-
-    def setProxy(self, addr, port, username=None, password=None, proxy_type=socks.SOCKS5):
-        # pip install PySocks
-        import socks
-        socks.set_default_proxy(
-            proxy_type, addr=addr, port=port, username=username, password=password
-        )
-        # socket.socket = socks.socksocket
-        self.socket = socks.socksocket
