@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+import time
 from saker.fuzzers.fuzzer import Fuzzer
 
 
@@ -26,3 +27,15 @@ class DoS(Fuzzer):
         for i in range(dictLength):
             r[str(i)] = (str(i), 'a' * strLength)
         return r
+
+    @classmethod
+    def slowWrite(cls, conn, req, interval=0.3):
+        for b in req:
+            conn.send(b.to_bytes(length=1, byteorder="little"))
+            time.sleep(interval)
+
+    @classmethod
+    def slowRead(cls, conn, interval=0.3):
+        while True:
+            conn.recv(1)
+            time.sleep(interval)
