@@ -6,9 +6,20 @@ from urllib.parse import quote
 from urllib.parse import unquote
 
 
-def b64e(s):
+def toBytes(s):
     if isinstance(s, str):
         s = s.encode()
+    return s
+
+
+def toStr(s):
+    if isinstance(s, bytes):
+        s = s.decode()
+    return s
+
+
+def b64e(s):
+    s = toBytes(s)
     return base64.b64encode(s).decode()
 
 
@@ -16,8 +27,7 @@ def b64d(s):
     '''
     auto handle url encode / url safe base64
     '''
-    if isinstance(s, bytes):
-        s = s.decode()
+    s = toStr(s)
     if '%' in s:
         s = unquote(s)
     if '-' in s or '_' in s:
@@ -27,13 +37,17 @@ def b64d(s):
     return base64.b64decode(s)
 
 
+def decodeURL(s):
+    return unquote(s)
+
+
 def doubleURL(s):
     return quote(quote(s))
 
 
 def hex(s):
-    return s.encode().hex()
+    return toBytes(s).hex()
 
 
 def unhex(s):
-    return bytes.fromhex(s).decode()
+    return bytes.fromhex(s)
