@@ -8,13 +8,17 @@ import pickle
 
 class Serializer(object):
 
-    def __init__(self, serializer='json', savepath='.'):
+    def __init__(self, serializer="json", savepath="."):
         super(Serializer, self).__init__()
-        if serializer == 'json':
-            self.suffix = 'json'
+        if serializer == "json":
+            self.suffix = "json"
             self.serializer = json
-        elif serializer == 'pickle':
-            self.suffix = 'pkl'
+            self.saveMode = "w"
+            self.readMode = "r"
+        elif serializer == "pickle":
+            self.suffix = "pkl"
+            self.saveMode = "wb"
+            self.readMode = "rb"
             self.serializer = pickle
         self.dir = os.path.abspath(savepath)
         if not os.path.exists(self.dir):
@@ -30,7 +34,7 @@ class Serializer(object):
         :param identifier: str. the identifier of variable
         :return: bool. status of save
         """
-        with open(self.getPath(identifier), 'wb') as fh:
+        with open(self.getPath(identifier), self.saveMode) as fh:
             self.serializer.dump(val, fh)
         return True
 
@@ -40,6 +44,9 @@ class Serializer(object):
         :param identifier: str. the identifier of variable
         :return: variable
         """
-        with open(self.getPath(identifier), 'rb') as fh:
+        with open(self.getPath(identifier), self.readMode) as fh:
             data = self.serializer.load(fh)
         return data
+
+    def remove(self, identifier):
+        os.unlink(self.getPath(identifier))
